@@ -2,8 +2,7 @@ from .exceptions import DependencyError, WkbError, SridError, DimensionalityErro
 from .hex import HexReader, HexWriter, HexBytes
 
 try:
-    import shapely.wkb
-    from shapely.geos import lgeos, WKBWriter
+    import shapely, shapely.wkb
     SHAPELY = True
 except ImportError:
     SHAPELY = False
@@ -40,8 +39,9 @@ class Geometry(object):
 
     From a Shapely object::
 
-        >>> from shapely.geometry import Point
-        >>> Geometry.from_shapely(Point((0, 0)), 3857)
+        >>> from shapely import Point
+        >>> point = Point(0, 0)
+        >>> Geometry.from_shapely(point, 3857)
         <Point: 'geometry(Point,3857)'>
 
     From any object supporting ``__geo_interface__``::
@@ -116,10 +116,10 @@ class Geometry(object):
         The Shapely geometry will not be modified.
         """
         if SHAPELY:
-            WKBWriter.defaults["include_srid"] = True
             if srid:
-                lgeos.GEOSSetSRID(sgeom._geom, srid)
-            return Geometry(sgeom.wkb_hex)
+                sgeom = shapely.set_srid(sgeom, srid)
+            wkb_hex = shapely.to_wkb(sgeom, include_srid=True, hex=True)
+            return Geometry(wkb_hex)
         else:
             raise DependencyError("Shapely")
 
@@ -223,7 +223,7 @@ class Geometry(object):
     def _to_shapely(self):
         if SHAPELY:
             sgeom = shapely.wkb.loads(self.wkb)
-            srid = lgeos.GEOSGetSRID(sgeom._geom)
+            srid = shapely.get_srid(sgeom)
             if srid == 0:
                 srid = None
             if (srid or self.srid) and srid != self.srid:
@@ -382,11 +382,11 @@ class _MultiGeometry(Geometry):
                 self._dimm = geometry.dimm
             elif self._dimm != geometry.dimm:
                 raise DimensionalityError("Mixed dimensionality in MultiGeometry")
-            if self.srid is None:
-                if geometry._srid is not None:
-                    self._srid = geometry.srid
-            elif self.srid != geometry.srid and geometry.srid is not None:
-                raise SridError("Mixed SRIDs in MultiGeometry")
+            if geometry._srid is not None:
+                if self._srid != geometry._srid:
+                    raise SridError("Geometry can not be different from SRID in MultiGeometry")
+                else:
+                    geometry._srid = None
 
     def _to_geojson_coordinates(self, dimz):
         coordinates = [g._to_geojson_coordinates(dimz=dimz) for g in self.geometries]
@@ -867,7 +867,8 @@ class MultiPoint(_MultiGeometry):
         >>> MultiPoint([p1, p2])
         <MultiPoint: 'geometry(MultiPointZ)'>
 
-    The dimensionality of all geometries in the collection must be identical.
+    The SRID and dimensionality of all geometries in the collection must be
+    identical.
     """
 
     _LWGEOMTYPE = 4
@@ -912,7 +913,8 @@ class MultiLineString(_MultiGeometry):
         >>> MultiLineString([l1, l2])
         <MultiLineString: 'geometry(MultiLineStringM)'>
 
-    The dimensionality of all geometries in the collection must be identical.
+    The SRID and dimensionality of all geometries in the collection must be
+    identical.
     """
 
     _LWGEOMTYPE = 5
@@ -952,24 +954,23 @@ class MultiPolygon(_MultiGeometry):
     ``MultiPolygon`` objects can be created directly from a list of ``Polygon``
     objects.
 
-        >>> p1 = Polygon([[(0, 0), (1, 0), (1, 1), (0, 1), (0, 0)]], srid=4326)
-        >>> p2 = Polygon([[(2, 2), (3, 2), (3, 3), (2, 3), (2, 2)]], srid=4326)
-        >>> MultiPolygon([p1, p2])
+        >>> p1 = Polygon([[(0, 0), (1, 0), (1, 1), (0, 1), (0, 0)]])
+        >>> p2 = Polygon([[(2, 2), (3, 2), (3, 3), (2, 3), (2, 2)]])
+        >>> MultiPolygon([p1, p2], srid=4326)
         <MultiPolygon: 'geometry(MultiPolygon,4326)'>
 
-    The dimensionality of all geometries in the collection must be identical.
+    The SRID and dimensionality of all geometries in the collection must be
+    identical.
     """
 
     _LWGEOMTYPE = 6
     __slots__ = ["__polygons__"]
 
-    def __init__(self, polygons=None, srid=None, dimz=False, dimm=False):
+    def __init__(self, polygons=None, srid=None):
         if self._wkb:
             self._polygons = None
         else:
             self._srid = srid
-            self._dimz = dimz
-            self._dimm = dimm
             self._polygons = polygons
             self._set_multi_metadata()
 
@@ -1004,7 +1005,8 @@ class GeometryCollection(_MultiGeometry):
         >>> GeometryCollection([p, l])
         <GeometryCollection: 'geometry(GeometryCollectionZ)'>
 
-    The dimensionality of all geometries in the collection must be identical.
+    The SRID and dimensionality of all geometries in the collection must be
+    identical.
     """
 
     _LWGEOMTYPE = 7
